@@ -42,8 +42,8 @@ namespace K3b {
 
         virtual bool questionYesNo( const QString& text,
                                     const QString& caption = QString(),
-                                    const KGuiItem& buttonYes = KStandardGuiItem::yes(),
-                                    const KGuiItem& buttonNo = KStandardGuiItem::no() ) = 0;
+                                    const KGuiItem& buttonYes = KStandardGuiItem::ok(),
+                                    const KGuiItem& buttonNo = KStandardGuiItem::cancel() ) = 0;
 
         /**
          * Use this if you need the user to do something before the job is able to continue.
