@@ -12,7 +12,7 @@
 #include "k3bdevice.h"
 #include "k3b_export.h"
 
-#include <KCddb/Cdinfo>
+#include <KCDDB/CDInfo>
 
 class QMimeData;
 
