@@ -31,7 +31,7 @@
 #include <QTemporaryFile>
 #include <QTimer>
 #include <QDebug>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QUrl>
 #include <QDomDocument>
 
@@ -280,7 +280,8 @@ void K3b::VcdJob::slotParseVcdxBuildOutput( const QString& line )
             if ( oper == "scan" ) {
                 // Scan Video Files
                 if ( m_stage == stageUnknown || pos < m_bytesFinished ) {
-                    const uint index = el.attribute( "id" ).remove( QRegExp( "sequence-" ) ).toUInt();
+                    static const QRegularExpression rx( "sequence-" );
+                    const uint index = el.attribute( "id" ).remove( rx ).toUInt();
 
                     m_currentWrittenTrack = m_doc->at( m_currentWrittenTrackNumber );
                     emit newSubTask( i18n( "Scanning video file %1 of %2 (%3)" , index + 1 , doc() ->numOfTracks() , m_currentWrittenTrack->fileName() ) );
@@ -571,4 +572,4 @@ QString K3b::VcdJob::jobDetails() const
                  : QString() ) );
 }
 
-
+#include "moc_k3bvcdjob.cpp"
