@@ -1,16 +1,7 @@
 /*
- *
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 1998-2007 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 #include "k3bvideodvdjob.h"
@@ -68,4 +59,4 @@ QString K3b::VideoDvdJob::jobDetails() const
                  : QString() ) );
 }
 
-
+#include "moc_k3bvideodvdjob.cpp"
