@@ -10,8 +10,6 @@
 #include "k3bfilesplitter.h"
 #include "k3b_i18n.h"
 
-#include <KCodecs>
-
 #include <QCryptographicHash>
 #include <QDebug>
 #include <QIODevice>
@@ -293,4 +291,4 @@ void K3b::Md5Job::stopAll()
     d->finished = true;
 }
 
-
+#include "moc_k3bmd5job.cpp"
