@@ -17,7 +17,7 @@ class K3bSoxEncoderConfigWidget : public K3b::PluginConfigWidget, Ui::base_K3bSo
     Q_OBJECT
 
 public:
-    explicit K3bSoxEncoderConfigWidget( QWidget* parent = 0, const QVariantList& args = QVariantList() );
+    explicit K3bSoxEncoderConfigWidget( QObject* parent, const KPluginMetaData& metaData, const QVariantList& args );
     ~K3bSoxEncoderConfigWidget() override;
 
 public Q_SLOTS:
