@@ -2,6 +2,6 @@
 #define K3BPLUGIN_I18N_H
 
 #define TRANSLATION_DOMAIN "k3b"
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #endif // K3BPLUGIN_I18N_H
