@@ -10,7 +10,7 @@
 #ifndef K3BDIROPERATOR_H
 #define K3BDIROPERATOR_H
 
-#include <KBookmarkManager>
+#include <KBookmarkOwner>
 #include <KDirOperator>
 #include <QUrl>
 
@@ -66,6 +66,7 @@ private Q_SLOTS:
 private:
     KBookmarkMenu* m_bmMenu;
     KActionMenu* m_bmPopup;
+    QAction* m_bmActionAddFileToProject;
 };
 }
 
