@@ -140,9 +140,6 @@ K3b::ExternalBinWidget::ExternalBinWidget( K3b::ExternalBinManager* manager, QWi
     connect( m_rescanButton, SIGNAL(clicked(bool)), this, SLOT(rescan()) );
 
     qRegisterMetaType<HelperProgramItem>();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    qRegisterMetaTypeStreamOperators<HelperProgramItem>("K3b::HelperProgramItem");
-#endif
 
     while (::group *g = ::getgrent()) {
         const QString groupName = QString::fromLocal8Bit(g->gr_name);
@@ -208,11 +205,7 @@ void K3b::ExternalBinWidget::slotChangePermissions()
     KAuth::Action action("org.kde.k3b.updatepermissions");
     action.setHelperId("org.kde.k3b");
 
-#if QT_VERSION_MAJOR == 5
-    action.setParentWidget(this);
-#else
     action.setParentWindow(window()->windowHandle());
-#endif
 
     QVariantMap args;
 
