@@ -21,7 +21,6 @@
 #include "k3baudiotrackaddingdialog.h"
 #include "k3baudiotrackdialog.h"
 #include "k3baudiotracksplitdialog.h"
-#include "k3baudiotracktrmlookupdialog.h"
 #include "k3baudiozerodata.h"
 #include "k3bmsfedit.h"
 #include "k3bview.h"
@@ -86,12 +85,6 @@ K3b::AudioViewImpl::AudioViewImpl( View* view, AudioDoc* doc, KActionCollection*
                                        actionCollection, "edit_source" );
     m_actionPlayTrack = createAction( m_view, i18n("Play Track"), "media-playback-start", 0, this, SLOT(slotPlayTrack()),
                                       actionCollection, "track_play" );
-    m_actionQueryMusicBrainz = createAction( m_view, i18n("Musicbrainz Lookup"), "musicbrainz", 0, this, SLOT(slotQueryMusicBrainz()),
-                                        actionCollection, "project_audio_musicbrainz");
-    m_actionQueryMusicBrainz->setToolTip( i18n("Try to determine meta information over the Internet") );
-    m_actionQueryMusicBrainzTrack = createAction( m_view, i18n("Musicbrainz Lookup"), "musicbrainz", 0, this, SLOT(slotQueryMusicBrainzTrack()),
-                                        actionCollection, "project_audio_musicbrainz_track");
-    m_actionQueryMusicBrainzTrack->setToolTip( i18n("Try to determine meta information over the Internet") );
     m_actionProperties = createAction( m_view, i18n("Properties"), "document-properties", 0, this, SLOT(slotTrackProperties()),
                                        actionCollection, "track_properties" );
     m_actionRemove = createAction( m_trackView, i18n("Remove"), "edit-delete", Qt::Key_Delete, this, SLOT(slotRemove()),
@@ -126,16 +119,7 @@ K3b::AudioViewImpl::AudioViewImpl( View* view, AudioDoc* doc, KActionCollection*
     m_trackView->addAction( m_actionMergeTracks );
     m_trackView->addAction( m_actionProperties );
     m_trackView->addAction( separator );
-    m_trackView->addAction( m_actionQueryMusicBrainzTrack );
-    m_trackView->addAction( separator );
     m_trackView->addAction( actionCollection->action("project_burn") );
-
-#ifndef ENABLE_MUSICBRAINZ
-    m_actionQueryMusicBrainz->setEnabled( false );
-    m_actionQueryMusicBrainz->setVisible( false );
-    m_actionQueryMusicBrainzTrack->setEnabled( false );
-    m_actionQueryMusicBrainzTrack->setVisible( false );
-#endif
 }
 
 
@@ -342,55 +326,6 @@ void K3b::AudioViewImpl::slotPlayTrack()
 }
 
 
-void K3b::AudioViewImpl::slotQueryMusicBrainz()
-{
-#ifdef ENABLE_MUSICBRAINZ
-    QList<AudioTrack*> tracks;
-    for( int i = 1; i <= m_doc->numOfTracks(); ++i ) {
-        tracks.push_back( m_doc->getTrack( i ) );
-    }
-
-    if( tracks.isEmpty() ) {
-        KMessageBox::error( m_view, i18n("Please add an audio track.") );
-        return;
-    }
-
-    // only one may use the tracks at the same time
-//     if( m_currentlyPlayingTrack &&
-//         tracks.containsRef( m_currentlyPlayingTrack ) )
-//         m_player->stop();
-
-    // now do the lookup on the files.
-    AudioTrackTRMLookupDialog dlg( m_view );
-    dlg.lookup( tracks );
-#endif
-}
-
-
-void K3b::AudioViewImpl::slotQueryMusicBrainzTrack()
-{
-#ifdef ENABLE_MUSICBRAINZ
-    const QModelIndexList indexes = m_trackView->selectionModel()->selectedRows();
-    QList<AudioTrack*> tracks;
-    tracksForIndexes( tracks, indexes );
-
-    if( tracks.isEmpty() ) {
-        KMessageBox::error( m_view, i18n("Please select an audio track.") );
-        return;
-    }
-
-    // only one may use the tracks at the same time
-//     if( m_currentlyPlayingTrack &&
-//         tracks.containsRef( m_currentlyPlayingTrack ) )
-//         m_player->stop();
-
-    // now do the lookup on the files.
-    AudioTrackTRMLookupDialog dlg( m_view );
-    dlg.lookup( tracks );
-#endif
-}
-
-
 void K3b::AudioViewImpl::slotSelectionChanged()
 {
     if( m_trackView->hasFocus() ) {
