@@ -1,8 +1,8 @@
 
 #include "k3btestutils.h"
 
-#include <QtCore/QModelIndex>
-#include <QtTest/QTest>
+#include <QModelIndex>
+#include <QTest>
 
 Q_DECLARE_METATYPE( QModelIndex )
 
